#!/usr/bin/env node

'use strict';

const program = require('commander');
const latestVersion = require('@ali/latest-version');
const chalk = require('chalk');
const packageJson = require('../package.json');
const script = require('../src/index.js');


const runScript = (cmd, options) => {
  script[cmd](options);
};

function parseCmd(argv) {
  program
    .version('1.0.0')
    .option('-c, --cmd [required]', 'Command name[extract]')
    .option('--path [optional]', 'Input path. Default value: ./')
    .option('--target-extensions [optional]', `Extensions to be parsed. Default value: '[".js", ".ts", ".jsx", ".tsx"]'`)
    .option('--exclude-dir-name [optional]', `Exclude directory. Default value: '["node_modules", "build"]'`)
    .option('--output [optional]', `export output path. Default value: './src/locales'`)
    .parse(argv);
  return program;
}

function execute() {
  const cmd = process.argv[3];
  const options = parseCmd(process.argv);
  switch (cmd) {
    case 'sync':
      runScript(cmd, options);
      break;
    case 'scan':
      runScript(cmd, options);
      break;
    case 'export':
      runScript(cmd, options);
      break;
    case 'translate':
      runScript(cmd, options);
      break;
    case 'audit':
      runScript(cmd, options);
      break;
    case 'detect':
      runScript(cmd, options);
      break;
    default:
      console.log(`Unkown cmd ${cmd}.`);
  }
}

latestVersion('@ali/onebox-intl-extract')(function (err, version) {
  if (err) {
    console.log('检测新版本失败', err);
  } else {
    if (packageJson.version !== version.latest) {
      console.log(chalk.yellow(`=============请更新版本===========`));
      console.log(chalk.yellow(`当前版本${packageJson.version}。最新版本${version.latest}. 请执行 tnpm ii @ali/onebox-intl-extract -D 安装最新版本`));
      console.log(chalk.yellow(`=============请更新版本===========`));
    }
  }
  execute();
});
